@@ -2,6 +2,12 @@
 // SPDX-License-Identifier: AGPL-3.0-or-later
 // There is NO WARRANTY.
 
+//! Otter game system (part thereeof)
+//!
+//! <https://www.chiark.greenend.org.uk/~ianmdlvl/otter/docs/README.html>
+//!
+//! This crate is intended for use only by other parts of Otter.
+
 // ==================== namespace preparation ====================
 
 pub mod imports {
@@ -328,10 +334,9 @@ pub mod cleanup_notify {
   use anyhow::Context;
   use fehler::{throw, throws};
   use libc::_exit;
-  use nix::errno::Errno::*;
   use nix::{unistd::*, fcntl::OFlag};
   use nix::sys::signal::*;
-  use nix::Error::Sys;
+  use nix::Error as NE;
   use void::Void;
   use std::io;
   use std::os::unix::io::RawFd;
@@ -353,7 +358,7 @@ pub mod cleanup_notify {
       match nix::unistd::read(fd, &mut buf) {
         Ok(0) => break,
         Ok(_) => throw!(io::Error::from_raw_os_error(libc::EINVAL)),
-        Err(Sys(EINTR)) => continue,
+        Err(NE::EINTR) => continue,
         _ => throw!(io::Error::last_os_error()),
       }
     }
@@ -398,7 +403,7 @@ pub mod cleanup_notify {
               for fd in 2.. {
                 if fd == notify_writing_end { continue }
                 let r = close(fd);
-                if fd > writing_end && matches!(r, Err(Sys(EBADF))) {
+                if fd > writing_end && matches!(r, Err(NE::EBADF)) {
                   break;
                 }                  
               }
@@ -485,14 +490,14 @@ pub fn reinvoke_via_bwrap(_opts: &Opts, current_exe: &str,
     .args("--unshare-net \
            --dev-bind / / \
            --tmpfs /tmp \
-           --die-with-parent".split(" "))
+           --die-with-parent".split(' '))
     .arg(current_exe);
 
   let (early, late) = {
     let mut still_early = true;
     env::args_os().skip(1)
       .partition::<Vec<_>,_>(|s| {
-        still_early &= early(&s);
+        still_early &= early(s);
         still_early
       })
   };
@@ -591,7 +596,7 @@ pub fn prepare_tmpdir<'x>(opts: &'x Opts, mut current_exe: &'x str) -> DirSubst
 
   let manifest_var = "CARGO_MANIFEST_DIR";
   let src: String = (|| Ok::<_,AE>(match env::var(manifest_var) {
-    Ok(dir) => dir.into(),
+    Ok(dir) => dir,
     Err(env::VarError::NotPresent) => start_dir.clone(),
     e@ Err(_) => throw!(e.context(manifest_var).err().unwrap()),
   }))()
@@ -627,7 +632,7 @@ usvg_bin = "@target@/release/usvg"
 authorized_keys = "@abstmp@/authorized_keys"
 ssh_proxy_command = "@target@/debug/otter-ssh-proxy --config @abstmp@/server-config.toml"
 
-debug_js_inject_file = "@src@/templates/log-save.js"
+debug_js_inject_file = "@src@/templates/test-inject.js"
 check_bundled_sources = false # For testing only! see LICENCE!
 
 fake_rng = []
@@ -636,9 +641,6 @@ fake_rng = []
 global_level = 'debug'
 
 [log.modules]
-rocket = 'error'
-_ = "error" # rocket
-# ^ comment these two out to see Tera errors, *sigh*
 
 'hyper::server' = 'info'
 "game::debugreader" = 'info'
@@ -790,7 +792,7 @@ impl DirSubst {
     let exe = ds.subst("@target@/debug/otter")?;
     let specs = self.subst("@src@/specs")?;
     let mut args: Vec<String> = vec![];
-    args.push("--config"  .to_owned()); args.push(prctx.resolve(&CONFIG));
+    args.push("--config"  .to_owned()); args.push(prctx.resolve(CONFIG));
     args.push("--spec-dir".to_owned()); args.push(prctx.resolve(&specs) );
     args.extend(xargs.to_args(ds));
     let dbg = format!("running {} {:?}", &exe, &args);
@@ -1037,7 +1039,7 @@ pub fn setup_core<O>(module_paths: &[&str]) ->
 
   if !opts.no_bwrap {
     reinvoke_via_bwrap(
-      &opts, &current_exe,
+      opts, &current_exe,
       &mut |s: &OsStr| s.to_str().unwrap().starts_with("--test=")
     )
       .context("reinvoke via bwrap")?;
@@ -1047,7 +1049,7 @@ pub fn setup_core<O>(module_paths: &[&str]) ->
   sleep(opts.pause.into());
 
   let cln = cleanup_notify::Handle::new()?;
-  let ds = prepare_tmpdir(&opts, &current_exe)?;
+  let ds = prepare_tmpdir(opts, &current_exe)?;
 
   let (mgmt_conn, server_child) =
     prepare_gameserver(&cln, &ds).did("setup game server")?;
