@@ -198,7 +198,7 @@ impl Ctx {
   #[throws(Explode)]
   fn ssh_remote(&mut self) {
     let ds = self.ds().also(&[
-      ("config", PathResolveContext::default().resolve(&CONFIG)),
+      ("config", PathResolveContext::default().resolve(CONFIG)),
     ]);
     let mut command = ds.gss(
       "--ssh-command=@src@/apitest/mock-ssh \
@@ -228,7 +228,7 @@ impl Ctx {
     static STATIC_TEST: &str = "# example static data -- for test\n";
 
     File::create(ds.subst("@authkeys@")?)?
-      .write(STATIC_TEST.as_bytes())?;
+      .write_all(STATIC_TEST.as_bytes())?;
 
     let set_keys = ds.gss(
       "--super --account ssh:test: set-ssh-keys \
@@ -245,7 +245,7 @@ impl Ctx {
 
     assert_eq!( BufReader::new(File::open(ds.subst("@authkeys@")?)?)
                 .lines().nth(2).unwrap().unwrap(),
-                STATIC_TEST.strip_suffix("\n").unwrap() );
+                STATIC_TEST.strip_suffix('\n').unwrap() );
 
     let ssh_command = ds.subst(
       "@src@/apitest/mock-ssh-restricted @authkeys@ '@dummy_key_data@'"
